==> nextcloud-22.2.0.tgz: nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "New text document" : "新しいテキストドキュメント",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
    "Reconnect" : "再接続",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディターの外部から変更されました。変更点を適用できません。",
    "File could not be loaded. Please check your internet connection." : "ファイルを読み込めませんでした。 インターネット接続を確認してください。",
    "Saving …" : "保存中 ...",
    "Saved" : "保存済み",
    "Last saved {lastSaved}" : "最終保存日 {lastSaved}",
    "Unsaved changes" : "保存していない変更点",
    "Enter your name so other users can see who is editing" : "自分の名前を入力して、他のユーザーの誰が編集中かを確認する",
    "Edit guest name" : "ゲスト名を編集",
    "Save guest name" : "ゲスト名を保存",
    "Insert emoji" : "絵文字を挿入",
    "Insert image" : "画像の挿入",
    "Insert an image" : "画像を追加",
    "Link file" : "ファイルをリンク",
    "Select file to link to" : "リンク先のファイルを選択",
    "Show author colors" : "記入者の色をつける",
    "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
    "Currently active users:" : "現在のアクティブユーザー:",
    "_and %n other editor_::_and %n other editors_" : ["他に%n人の編集者"],
    "Show rich workspaces" : "Readme.mdを表示",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "Edit" : "編集",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Bold" : "太字",
    "Italic" : "斜体",
    "Strikethrough" : "取り消し線",
    "Headings" : "見出し",
    "Heading 1" : "見出し1",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "Heading 6" : "見出し6",
    "Unordered list" : "番号なしのリスト",
    "Ordered list" : "順序付きリスト",
    "ToDo list" : "ToDo リスト",
    "Blockquote" : "引用",
    "Code block" : "コードブロック",
    "Emoji picker" : "絵文字選択",
    "Retry" : "再試行",
    "Unpushed changes" : "プッシュされていない変更"
},
"nplurals=1; plural=0;");

==> nextcloud-22.2.9.tgz: nextcloud/apps/text/l10n/ja.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "新規のテキストファイル",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブのサイズを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードされたファイルは、HTMLフォームで指定されたMAX_FILE_SIZEディレクティブ制限を超えています",
    "The file was only partially uploaded" : "ファイルは部分的にしかアップロードされていません",
    "No file was uploaded" : "ファイルがアップロードされていません",
    "Missing a temporary folder" : "一時保存フォルダーが見つかりません",
    "Could not write file to disk" : "ファイルをディスクに書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張機能がファイルのアップロードを停止しました",
    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "テキストドキュメント",
    "Readme" : "Readme",
    "Text" : "テキスト",
    "📝 Collaborative document editing" : "📝 共同文書編集",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "**📝共同文書編集！**\n\n- **📝 集中執筆：集中モードで、必要なフォーマットだけ。\n- **🙋 一緒に仕事をする：**友達や同僚と、Nextcloudを使っていようとなかろうと、共有して共同作業しよう！\n- **💾 オープンフォーマット:** ファイルは[Markdown](https://en.wikipedia.org/wiki/Markdown)として保存されるので、他のテキストアプリからも編集できます。\n- **✊ 強固な基盤：**私たちは[🦉 ProseMirror](https://prosemirror.net)をベースにした[🐈 tiptap](https://tiptap.scrumpy.io)を使用しています - 本当にありがとうございます！",
    "Use current version" : "現在のバージョンを使用",
    "Use the saved version" : "保存済みのバージョンを使用",
    "Insert an image" : "画像を追加",
    "Document idle for {timeout} minutes, click to continue editing" : "ドキュメントが{timeout}分間アイドル状態です。クリックして編集を続行します",
    "Reconnect" : "再接続",
    "The document has been changed outside of the editor. The changes cannot be applied." : "ドキュメントがエディターの外部から変更されました。変更点を適用できません。",
    "File could not be loaded. Please check your internet connection." : "ファイルを読み込めませんでした。 インターネット接続を確認してください。",
    "Saving …" : "保存中 ...",
    "Saved" : "保存済み",
    "Last saved {lastSaved}" : "最終保存日 {lastSaved}",
    "Unsaved changes" : "保存していない変更点",
    "Edit guest name" : "ゲスト名を編集",
    "Guest" : "ゲスト",
    "Save guest name" : "ゲスト名を保存",
    "Formatting help" : "ヘルプの書式設定",
    "Keyboard shortcuts" : "キーボードショートカット",
    "Bold" : "太字",
    "Bold text" : "太字",
    "Ctrl" : "Ctrl",
    "Italic" : "斜体",
    "Strikethrough" : "取り消し線",
    "Shift" : "移動",
    "Heading 1" : "見出し1",
    "Heading 6" : "見出し6",
    "Unordered list" : "番号なしのリスト",
    "Ordered list" : "順序付きリスト",
    "Checklist" : "チェックリスト",
    "Blockquote" : "引用",
    "Code block" : "コードブロック",
    "Upload from computer" : "コンピュータからアップロード",
    "Add Link" : "リンクを追加",
    "Link file" : "ファイルをリンク",
    "Remove Link" : "リンクを削除",
    "Select file to link to" : "リンク先のファイルを選択",
    "guest" : "ゲスト",
    "Show author colors" : "記入者の色をつける",
    "Author colors are only shown until everyone has closed the document." : "記入者の色は、全員がドキュメントを閉じるまで表示されます。",
    "Show rich workspaces" : "各フォルダのReadmeを表示",
    "Add notes, lists or links …" : "ノート、リスト、リンクを追加...",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Headings" : "見出し",
    "Heading 2" : "見出し2",
    "Heading 3" : "見出し3",
    "Heading 4" : "見出し4",
    "Heading 5" : "見出し5",
    "ToDo list" : "ToDo リスト",
    "Info" : "情報",
    "Success" : "完了",
    "Warning" : "警告",
    "Insert emoji" : "絵文字を挿入",
    "Insert image" : "画像の挿入",
    "Alt" : "Alt",
    "Edit" : "編集",
    "New text document" : "新しいテキストドキュメント",
    "Enter your name so other users can see who is editing" : "自分の名前を入力して、他のユーザーの誰が編集中かを確認する",
    "Currently active users:" : "現在のアクティブユーザー:",
    "_and %n other editor_::_and %n other editors_" : ["他に%n人の編集者"],
    "Emoji picker" : "絵文字選択",
    "Participants" : "参加者"
},
"nplurals=1; plural=0;");
